==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CsrMetadata.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CsrMetadataSubject;
import com.okta.sdk.resource.model.CsrMetadataSubjectAltNames;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CsrMetadata
 */
@JsonPropertyOrder({ CsrMetadata.JSON_PROPERTY_SUBJECT, CsrMetadata.JSON_PROPERTY_SUBJECT_ALT_NAMES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class CsrMetadata implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SUBJECT = "subject";
    private CsrMetadataSubject subject;

    public static final String JSON_PROPERTY_SUBJECT_ALT_NAMES = "subjectAltNames";
    private CsrMetadataSubjectAltNames subjectAltNames;

    public CsrMetadata() {
    }

    public CsrMetadata subject(CsrMetadataSubject subject) {

        this.subject = subject;
        return this;
    }

    /**
     * Get subject
     *
     * @return subject
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CsrMetadataSubject getSubject() {
        return subject;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSubject(CsrMetadataSubject subject) {
        this.subject = subject;
    }

    public CsrMetadata subjectAltNames(CsrMetadataSubjectAltNames subjectAltNames) {

        this.subjectAltNames = subjectAltNames;
        return this;
    }

    /**
     * Get subjectAltNames
     *
     * @return subjectAltNames
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUBJECT_ALT_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CsrMetadataSubjectAltNames getSubjectAltNames() {
        return subjectAltNames;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT_ALT_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSubjectAltNames(CsrMetadataSubjectAltNames subjectAltNames) {
        this.subjectAltNames = subjectAltNames;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrMetadata csrMetadata = (CsrMetadata) o;
        return Objects.equals(this.subject, csrMetadata.subject)
                && Objects.equals(this.subjectAltNames, csrMetadata.subjectAltNames);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(subject, subjectAltNames);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrMetadata {\n");
        sb.append("    subject: ").append(toIndentedString(subject)).append("\n");
        sb.append("    subjectAltNames: ").append(toIndentedString(subjectAltNames)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CsrMetadata.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CsrMetadataSubject;
import com.okta.sdk.resource.model.CsrMetadataSubjectAltNames;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CsrMetadata
 */
@JsonPropertyOrder({ CsrMetadata.JSON_PROPERTY_SUBJECT, CsrMetadata.JSON_PROPERTY_SUBJECT_ALT_NAMES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CsrMetadata implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SUBJECT = "subject";
    private CsrMetadataSubject subject;

    public static final String JSON_PROPERTY_SUBJECT_ALT_NAMES = "subjectAltNames";
    private CsrMetadataSubjectAltNames subjectAltNames;

    public CsrMetadata() {
    }

    public CsrMetadata subject(CsrMetadataSubject subject) {

        this.subject = subject;
        return this;
    }

    /**
     * Get subject
     *
     * @return subject
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CsrMetadataSubject getSubject() {
        return subject;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSubject(CsrMetadataSubject subject) {
        this.subject = subject;
    }

    public CsrMetadata subjectAltNames(CsrMetadataSubjectAltNames subjectAltNames) {

        this.subjectAltNames = subjectAltNames;
        return this;
    }

    /**
     * Get subjectAltNames
     *
     * @return subjectAltNames
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUBJECT_ALT_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CsrMetadataSubjectAltNames getSubjectAltNames() {
        return subjectAltNames;
    }

    @JsonProperty(JSON_PROPERTY_SUBJECT_ALT_NAMES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSubjectAltNames(CsrMetadataSubjectAltNames subjectAltNames) {
        this.subjectAltNames = subjectAltNames;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrMetadata csrMetadata = (CsrMetadata) o;
        return Objects.equals(this.subject, csrMetadata.subject)
                && Objects.equals(this.subjectAltNames, csrMetadata.subjectAltNames);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(subject, subjectAltNames);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrMetadata {\n");
        sb.append("    subject: ").append(toIndentedString(subject)).append("\n");
        sb.append("    subjectAltNames: ").append(toIndentedString(subjectAltNames)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
